@media screen and (min-width: 60em) {
    .ui-mobile [data-role="page"], .ui-page {
        width: 80%;
        max-width: 60em;
        margin-left: auto;
        margin-right: auto;
        position: relative;
        border-left: 1px solid #999;
        border-right: 1px solid #999;
    }
}
