@import url("themes.css");
@import url("lib/jquery.mobile.icons.css");
@import url("lib/jquery.mobile.structure.css");
@import url("lib/leaflet.css");
@import url("lib/leaflet.draw.css");
@import url("{{ project_name }}/main.css");
@import url("{{ project_name }}/responsive.css");
