<!DOCTYPE html>

<!--
NOTE: This template is only meant to provide a bootstrap to help new projects
get up and running with wq.  Please throw this out and replace it with your own
interesting and unique designs, styles and layouts.  The sky is the limit!
-->
<html manifest="{{ project_name }}.appcache">
  <head>
    <title>{{ project_name }} Project</title>
    <meta name="apple-mobile-web-app-capable" content="yes">
    <link rel="manifest" href="manifest.json">
    {% templatetag openvariable %}>head{% templatetag closevariable %}
  </head>
  <body>
    <div data-role="page" class="ui-page">
      <div data-role="header">
        <h1>{{ project_name }} Project</h1>
      </div>
      <div role="main" class="ui-content">
        <p>Hello, world!</p>
        <ul data-role="listview">
          <li><a href="{% templatetag openvariable %}rt{% templatetag closevariable %}/login">Log In</a></li>
          <li><a href="{% templatetag openvariable %}rt{% templatetag closevariable %}/places">Places</a></li>
          <li><a href="{% templatetag openvariable %}rt{% templatetag closevariable %}/observations">Observations</a></li>
        </ul>
      </div>
      <div id="index-map" class="map list-map"></div>
      <p class="footer">
        {{ project_name }} v{% templatetag openvariable %}version{% templatetag closevariable %}
        &bull;
        Powered by <a href="https://wq.io/">wq</a>
      </p>
    </div>
  </body>
</html>
