<meta name="viewport" content="width=device-width,initial-scale=1,maximum-scale=1,minimum-scale=1,user-scalable=yes" />
<link rel="stylesheet" href="{% templatetag openvariable %}rt{% templatetag closevariable %}/css/{{ project_name }}.css?v={% templatetag openvariable %}version{% templatetag closevariable %}">
<script>
    var require = {"urlArgs": "v={% templatetag openvariable %}version{% templatetag closevariable %}"};
</script>
<script src="{% templatetag openvariable %}rt{% templatetag closevariable %}/js/lib/require.js" data-main="{% templatetag openvariable %}rt{% templatetag closevariable %}/js/{{ project_name }}"></script>
