{% verbatim %}
{{#unsyncedItems}}
<li data-icon="{{#error}}alert{{/error}}{{^error}}minus{{/error}}">
  <a href="{{rt}}/outbox/{{id}}/edit">
    {{#data}}
    {{#photo}}
    <img src="{{image_url}}" alt="Observation on {{date}}">
    {{/photo}}
    {{^photo}}
    <img src="{{rt}}/images/empty.png" alt="No Image">
    {{/photo}}
    Observation on {{date}}
    {{/data}}
  </a>
</li>
{{/unsyncedItems}}
<li>
  <div class="ui-grid-a ui-responsive">
    <div class="ui-block-a">
      {{#is_authenticated}}
      <button class="sync" data-icon="refresh"
          onclick="require('wq/app').sync(true);">
        {{#syncing}}Syncing...{{/syncing}}
        {{^syncing}}Sync Now{{/syncing}}
      </button>
      {{/is_authenticated}}
      {{^is_authenticated}}
      <a href="{{rt}}/login" data-role="button" data-icon="lock">
        Log in to Sync
      </a>
      {{/is_authenticated}}
    </div>
    <div class="ui-block-b">
      <button type="button" data-icon="delete"
          onclick="if(confirm('Empty Outbox?'))require('wq/app').emptyOutbox();">
        Discard
      </button>
    </div>
  </div>
</li>
{% endverbatim %}
